package
Version:
v1.0.4
Opens a new window with list of versions in this module.
Published: Nov 27, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func LogDebug(ctx context.Context, args ...interface{})
-
func LogDebugf(ctx iris.Context, format string, args ...interface{})
-
func LogError(ctx iris.Context, args ...interface{})
-
func LogErrorf(ctx iris.Context, format string, args ...interface{})
-
func LogInfo(ctx iris.Context, args ...interface{})
-
func LogInfof(ctx iris.Context, format string, args ...interface{})
-
func LogWarn(ctx iris.Context, args ...interface{})
-
func LogWarnf(ctx iris.Context, format string, args ...interface{})
LogDebug will print when logger's Level is debug.
LogDebugf will print when logger's Level is debug.
LogError will print only when logger's Level is error, warn, info or debug.
LogErrorf will print only when logger's Level is error, warn, info or debug.
LogInfo will print when logger's Level is info or debug.
LogInfof will print when logger's Level is info or debug.
LogWarn will print when logger's Level is warn, info or debug.
LogWarnf will print when logger's Level is warn, info or debug.
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.